@@ -150,17 +150,18 @@ class ORM(object):
     def rev(self, v):
         # first make sure the cursor is not before the start of this branch
         branch = self.branch
-        self.cursor.execute(
-            "SELECT parent, parent_rev FROM branches WHERE branch=?;",
-            (branch,)
-        )
-        (parent, parent_rev) = self.cursor.fetchone()
-        if v < int(parent_rev):
-            raise ValueError(
-                "The revision number {revn} "
-                "occurs before the start of "
-                "the branch {brnch}".format(revn=v, brnch=branch)
+        if branch != 'master':
+            self.cursor.execute(
+                "SELECT parent, parent_rev FROM branches WHERE branch=?;",
+                (branch,)
             )
+            (parent, parent_rev) = self.cursor.fetchone()
+            if v < int(parent_rev):
+                raise ValueError(
+                    "The revision number {revn} "
+                    "occurs before the start of "
+                    "the branch {brnch}".format(revn=v, brnch=branch)
+                )
         self.cursor.execute(
             "UPDATE global SET value=? WHERE key='rev';",
             (v,)
